@@ -1,6 +1,9 @@
 unless ENV['DEBIAN_DISABLE_RUBYGEMS_INTEGRATION']
 
 class << Gem
+  OPERATING_SYSTEM_DEFAULTS = {
+    :ssl_ca_cert => '/etc/ssl/certs/ca-certificates.crt'
+  }
 
   alias :upstream_default_dir :default_dir
   def default_dir
@@ -17,10 +20,16 @@ class << Gem
     extra_path = nil
     if RbConfig::CONFIG['ruby_version'] == '2.1.0'
       extra_path = File.join('/usr/share/rubygems-integration', '2.1')
+    elsif RbConfig::CONFIG['ruby_version'] == '2.2.0'
+      extra_path = File.join('/usr/share/rubygems-integration', '2.2')
     end
 
+    arch = Gem::ConfigMap[:arch]
+    api_version = Gem::ConfigMap[:ruby_version]
+
     upstream_default_path + [
-      File.join('/usr/share/rubygems-integration', Gem::ConfigMap[:ruby_version]),
+      "/usr/lib/#{arch}/rubygems-integration/#{api_version}",
+      File.join('/usr/share/rubygems-integration', api_version),
       extra_path,
       '/usr/share/rubygems-integration/all'
     ].compact
